#
# spec file for package python-ruamel.yaml
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ruamel.yaml
Version:        0.15.44
Release:        13.7
Summary:        Python YAML parser
License:        MIT
Group:          Development/Languages/Python
URL:            https://bitbucket.org/ruamel/yaml
Source:         https://files.pythonhosted.org/packages/source/r/ruamel.yaml/ruamel.yaml-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%ifpython2
Requires:       python-ruamel.ordereddict
%endif
%python_subpackages

%description
ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation
of comments, seq/map flow style, and map key order

%prep
%setup -q -n ruamel.yaml-%{version}
rm -rf *egg-info

%build
%python_build

%install
%python_install --single-version-externally-managed
%python_exec %fdupes -s %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%{python_sitearch}/_ruamel_yaml*.so
%{python_sitearch}/ruamel
%{python_sitearch}/ruamel.yaml-%{version}-py%{python_version}-nspkg.pth
%{python_sitearch}/ruamel.yaml-%{version}-py%{python_version}.egg-info

%changelog
* Sun Jul 15 2018 mimi.vx@gmail.com
- update to 0.15.44
  * fix for losing precision when roundtripping floats by
  * decoding unicode escaped tags on Python2
  * add detection of C-compile failure
  * fix regression showing only on narrow Python 2.7
  * ``register_class()`` now returns class
* Wed Apr  4 2018 mimi.vx@gmail.com
- update to 0.15.37
  * fix incompatibility of C extension with 3.7
* Tue Jan  9 2018 mimi.vx@gmail.com
- update to 0.15.35
  * allow None as stream when specifying transform parameters to YAML.dump()
* Thu Oct 12 2017 mimi.vx@gmail.com
- update to 0.15.34
  * fix for issue 157: CDumper not dumping floats
  * support for “undefined” round-tripping tagged scalar objects
  * fix issue 148: replace cryptic error message when using !!timestamp with
  an incorrectly formatted or non- scalar.
  * allow setting yaml.default_flow_style = None (default: False) for for typ='rt'.
  * fix for issue 149: multiplications on ScalarFloat now return float
  * fix Comment dumping
  * fix for issue with “compact JSON” not parsing: {"in":{},"out":{}}
  * fix issue #51: different indents for mappings and sequences
  * fix for flow sequence/mapping as element/value of block sequence
  with sequence-indent minus dash-offset not equal two.
  * fix issue #61: merge of merge cannot be __repr__-ed
  * fix issue 62, YAML 1.2 allows ? and : in plain scalars if non-ambigious
  * fix lists within lists which would make comments disappear
  * fix for disappearing comment after empty flow sequence
  * fix for problem with dumping (unloaded) floats
  * added ScalarFloat which supports roundtripping of 23.1, 23.100, 42.00E+56,
  0.0, -0.0 etc. while keeping the format. Underscores in mantissas
  are not preserved/supported
  * (finally) fixed longstanding issue 23, now handling comment between block
  mapping key and value correctly
  * warn on YAML 1.1 float input that is incorrect
  * allow setting of boolean representation (false, true)
  by using: yaml.boolean_representation = [u'False', u'True']
  * fix for round_tripping integers on 2.7.X > sys.maxint
  * fix for round_tripping singe excl. mark tags doubling
  * fix for writing unicode in new API,
  * added object constructor for rt, decorator yaml_object to replace YAMLObject.
  * fix for problem using load_all with Path() instance
  * fix for load_all in combination with zero indent block style literal
  (pure=True only!)
  * missing pure attribute on YAML useful for implementing !include tag
  constructor for including YAML files in a YAML file
  * some documentation improvements
  * trigger of doc build on new revision
  * support for Unicode supplementary Plane output
  * fix for issue 135, typ=’safe’ not dumping in Python 2.7
  * fix for issue 133, in setup.py: change ModuleNotFoundError to ImportError
  * suppress duplicate key warning on mappings with merge keys
  * remove fatal dependency of setup.py on wheel package
  * fix for issue 130, regression in nested merge keys
  * top level PreservedScalarString not indented if not explicitly asked to
  * some mypy additions
  * fix for issue 127: tagged scalars were always quoted and seperated by
  a newline when in a block sequence
  * allow plug-in install via install ruamel.yaml[jinja2]
  * add plug-in mechanism for load/dump pre resp. post-processing
  * a set() with duplicate elements now throws error in rt loading
  * support for toplevel column zero literal/folded scalar in explicit documents
  * repeat load() on a single YAML() instance would fail.
  * transform parameter on dump that expects a function taking a string
  and returning a string. This allows transformation of the output before
  it is written to stream. This forces creation of the complete output in memory!
  * some updates to the docs
  * update to conform to mypy 0.511: mypy –strict
  * duplicate keys in mappings generate an error
  * dependecy on ruamel.ordereddict for 2.7 now via extras_require
  * it is now allowed to pass in a pathlib.Path as “stream” parameter
  to all load/dump functions
  * passing in a non-supported object (e.g. a string) as “stream” will result
  in a much more meaningful YAMLStreamError.
  * assigning a normal string value to an existing CommentedMap key
  or CommentedSeq element will result in a value cast to the previous
  value’s type if possible.
  * added YAML class for new API
  * fix for issue 119, deepcopy not returning subclasses
  * fix for issue 103 allowing implicit documents after document end marker
  line (...) in YAML 1.2
  * fix problem with emitting using cyaml
* Mon Apr 24 2017 aloisio@gmx.com
- Update to 0.14.9 (see included CHANGES file)
- Converted to single-spec
- LICENSE file is now provided internally, so dropped Source1
- Dropped python-ruamel.ordereddict as build requirement
* Tue Oct 11 2016 rjschwei@suse.com
- Initial build    (FATE#321630, bsc#1002895)
  + Include in SLES 12
  + Version 0.12.14
